cooltools.lib package
=====================

numutils
--------

.. automodule:: cooltools.lib.numutils
   :members:
   :undoc-members:
   :show-inheritance:

peaks
-----

.. automodule:: cooltools.lib.peaks
   :members:
   :undoc-members:
   :show-inheritance:

plotting
--------

.. automodule:: cooltools.lib.plotting
   :members:
   :undoc-members:
   :show-inheritance:

runlength
---------

.. automodule:: cooltools.lib.runlength
   :members:
   :undoc-members:
   :show-inheritance:
